@@ -24,7 +24,11 @@ def getShuffle(ratios,total):
             except:
                 print("warning:parse seed failed,use default 17")
     
-    files = os.listdir("./")
+    listdir = os.listdir("./")
+    files = []
+    for item in listdir:
+        if os.path.isfile(os.path.join("./",item)):
+            files.append(item)
     
     random.seed(seed)
     random.shuffle(files)
@@ -32,9 +36,10 @@ def getShuffle(ratios,total):
     spl_s = 0
     
     for r in range(len(ratios)):
-        spl_e = int(len(files)*(ratios[r]/total))+spl_s + 1
+        spl_e = int(len(files)*(ratios[r]/total))+spl_s
         images = files[spl_s:spl_e]
-        
+        if r == len(ratios) -1:
+            images = files[spl_s:]
         spl_s = spl_e
         dirname = "{}_{}".format(r+1,ratios[r])
         movFile(images,dirname)
